package biz.capitalware.mqfm.action.objects;

import java.io.File;
import java.util.ArrayList;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class holds the values for the Copy action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class CopyObject extends FMFileObject
{
   public String     srcFilename = null;
   public String     toFilename = null;
   public String     targetDir = null;
   public boolean    createDir = false;

   /**
    * The constructor
    */
   public CopyObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (srcFilename != null)
         srcFilename   = Tokens.replace(srcFilename, MQFM.userProperties);
      if (toFilename != null)
         toFilename = Tokens.replace(toFilename, MQFM.userProperties);
      if (targetDir != null)
         targetDir  = Tokens.replace(targetDir, MQFM.userProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      /* Do we need to create the directory? */
      if (createDir)
      {
         if (!(new File(targetDir).exists()))
         {
            if ((new File(targetDir)).mkdirs())
               MQFM.logger.info("Successfully created directory: " + targetDir);
            else
               throw new IllegalArgumentException("Error: Cannot create directory: " + targetDir);
         }
      }
      else if (!(new File(targetDir).exists()))
         throw new IllegalArgumentException("Target directory '"+targetDir+"' does not exit.");
      
      if (srcFilename == null)
         throw new IllegalArgumentException("Error: You must specify a filename for the Copy action.");

      if (targetDir == null)
         throw new IllegalArgumentException("Error: You must specify a TargetDirectory for the Copy action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      MQFM.logger.info("     FileName             = " + srcFilename);
      MQFM.logger.info("     Target Directory     = " + targetDir);
      MQFM.logger.info("     ToFileName           = " + (toFilename == null ? "":toFilename));
      MQFM.logger.info("     Create Directory     = " + createDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      String file;

      if (srcFilename.indexOf(File.separator) != -1 )
      {
         int x = srcFilename.lastIndexOf(File.separator);

         String dir   = srcFilename.substring(0, x);
         String fname = srcFilename.substring(x+1);

         file = "<"+Constants.FILE_ELEMENT+" "+Constants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+Constants.FILE_ELEMENT+">";
      }
      else
         file = "<"+Constants.FILE_ELEMENT+">"+srcFilename+"</"+Constants.FILE_ELEMENT+">";
      
      if (toFilename == null)
         al.add("<"+Constants.COPY_ELEMENT+" "+Constants.TO_DIR_ATTRIBUTE+"=\""+targetDir+"\">"+LINE_SEPARATOR);
      else
         al.add("<"+Constants.COPY_ELEMENT+" "+Constants.TO_DIR_ATTRIBUTE+"=\""+targetDir+"\" "+Constants.TO_FILE_ATTRIBUTE+"=\""+toFilename+">"+LINE_SEPARATOR);
      
      al.add("  "+file+LINE_SEPARATOR);
      al.add("</"+Constants.COPY_ELEMENT+">"+LINE_SEPARATOR);

      return al;
   }
}
