package biz.capitalware.mqfm.action.objects;

import java.io.File;
import java.util.ArrayList;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class holds the values for the Rename action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class RenameObject extends FMFileObject
{
   public String  srcFilename = null;
   public String  toFilename = null;

   /**
    * The constructor
    */
   public RenameObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (srcFilename != null)
         srcFilename   = Tokens.replace(srcFilename, MQFM.userProperties);
      if (toFilename != null)
         toFilename = Tokens.replace(toFilename, MQFM.userProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (srcFilename == null)
         throw new IllegalArgumentException("Error: You must specify a FileName for the Rename action.");

      if (toFilename == null)
         throw new IllegalArgumentException("Error: You must specify a ToFileName for the Rename action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      MQFM.logger.info("     FileName             = " + srcFilename);
      MQFM.logger.info("     ToFileName           = " + toFilename);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      String file;

      if (srcFilename.indexOf(File.separator) != -1 )
      {
         int x = srcFilename.lastIndexOf(File.separator);

         String dir   = srcFilename.substring(0, x);
         String fname = srcFilename.substring(x+1);

         file = "<"+Constants.FILE_ELEMENT+" "+Constants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+Constants.FILE_ELEMENT+">";
      }
      else
         file = "<"+Constants.FILE_ELEMENT+">"+srcFilename+"</"+Constants.FILE_ELEMENT+">";
      
      al.add("<"+Constants.FILE_ELEMENT+" "+Constants.TO_FILE_ATTRIBUTE+"=\""+toFilename+">"+LINE_SEPARATOR);
      al.add("  "+file+LINE_SEPARATOR);
      al.add("</"+Constants.FILE_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }
}
