package biz.capitalware.mqfm.action.objects;

import java.io.File;
import java.util.ArrayList;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class holds the values for the UnZip action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class UnZipObject extends FMFileObject
{
   public String     targetDir = null;
   public String     zipFilename = null;
   public boolean    createDir = false;

   /**
    * The constructor
    */
   public UnZipObject()
   {
      super();
   }

   /**
    * Process tokens in Action Object's variables
    */
   public void performTokenization()
   {
      if (zipFilename != null)
         zipFilename   = Tokens.replace(zipFilename, MQFM.userProperties);
      if (targetDir != null)
         targetDir = Tokens.replace(targetDir, MQFM.userProperties);
   }

   /**
    * Verify the values in the object.
    */
   public void checkObject()
   {
      if (targetDir == null)
         throw new IllegalArgumentException("Error: You must specify a TargetDirectory for the UnTar action.");
      
      /* Do we need to create the directory? */
      if (createDir)
      {
         if (!(new File(targetDir).exists()))
         {
            if ((new File(targetDir)).mkdirs())
               MQFM.logger.info("Successfully created directory: " + targetDir);
            else
               throw new IllegalArgumentException("Error: Cannot create directory: " + targetDir);
         }
      }
      else if (!(new File(targetDir).exists()))
         throw new IllegalArgumentException("Target directory '"+targetDir+"' does not exit.");

      if (zipFilename == null)
         throw new IllegalArgumentException("Error: You must specify a ToFileName for the UnZip action.");
   }

   /**
    * Output the info
    * @param logger
    */
   public void printValues()
   {
      MQFM.logger.info("     UnZip FileName       = " + zipFilename);
      MQFM.logger.info("     Target Directory     = " + targetDir);
      MQFM.logger.info("     Create Directory     = " + createDir);
   }
   
   /**
    * Convert the object to a string.
    * @return s
    */
   public ArrayList<String> toStringArray()
   {
      ArrayList<String> al = new ArrayList<String>();
      String file;

      if (zipFilename.indexOf(File.separator) != -1 )
      {
         int x = zipFilename.lastIndexOf(File.separator);

         String dir   = zipFilename.substring(0, x);
         String fname = zipFilename.substring(x+1);

         file = "<"+Constants.FILE_ELEMENT+" "+Constants.DIR_ATTRIBUTE+"=\""+dir+"\">"+fname+"</"+Constants.FILE_ELEMENT+">";
      }
      else
         file = "<"+Constants.FILE_ELEMENT+">"+zipFilename+"</"+Constants.FILE_ELEMENT+">";
      
      al.add("<"+Constants.UNZIP_ELEMENT+" "+Constants.TO_DIR_ATTRIBUTE+"=\""+targetDir+"\">"+LINE_SEPARATOR);
      al.add("  "+file+LINE_SEPARATOR);
      al.add("</"+Constants.UNZIP_ELEMENT+">"+LINE_SEPARATOR);
      
      return al;
   }
}
