package biz.capitalware.mqfm.actions;

import java.io.File;
import java.io.IOException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.CopyObject;
import biz.capitalware.mqfm.handlers.IO;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.MQFMException;

/**
 * This class will handle the copy action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class CopyAction extends FMAction
{
   private CopyObject   co;

   /**
    * The constructor
    * @param co
    * @param logger
    */
   public CopyAction(CopyObject co)
   {
      super(co.actionName);
      this.co = co;
   }

   /**
    * Perform the copy work.
    */
   public int doWork()
   {
      int exitCode = 0;
      co.printValues();

      if (co.srcFilename.indexOf('*') != -1)
         exitCode = handleManyFile();
      else
         exitCode = handleOneFile();

      if (!co.onErrorFail)
         exitCode = 0; /* reset back to zero */
      
      return exitCode;
   }

   /**
    * Copy a single file
    * @return exitCode
    */
   private int handleOneFile()
   {
      int exitCode = 0;
      String toPathAndFilename;
      String toFilename = co.toFilename;

      if (toFilename == null)
         toFilename = IO.getFileName(co.srcFilename);

      toPathAndFilename = IO.apendFileToPath(co.targetDir, toFilename);

      toPathAndFilename = Tokens.replace(co.actionName, toPathAndFilename, IO.getFileName(co.srcFilename), 1, MQFM.userProperties);

      try
      {
         IO.copyFile(co.srcFilename, toPathAndFilename);
         co.fileCount++;
      }
      catch (MQFMException e)
      {
         exitCode = 8;
      }

      return exitCode;
   }

   /**
    * Copy a many files
    * @return exitCode
    */
   private int handleManyFile()
   {
      int exitCode = 0;
      String toPathAndFilename;
      File[] fileList;
      
      try
      {
         fileList = IO.getFilteredFileList(co.srcFilename);
         
         for (int i=0; i < fileList.length; i++)
         {
            String toFilename;

            if (co.toFilename == null)
               toFilename = fileList[i].getName();
            else
               toFilename = co.toFilename;

            toPathAndFilename = IO.apendFileToPath(co.targetDir, toFilename);

            toPathAndFilename = Tokens.replace(co.actionName, toPathAndFilename, fileList[i].getName(), i+1, MQFM.userProperties);

            try
            {
               IO.copyFile(fileList[i].toString(), toPathAndFilename);
               co.fileCount++;
            }
            catch (MQFMException e)
            {
               exitCode = 8;
            }
         }
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }

      return exitCode;
   }
}
