package biz.capitalware.mqfm.actions;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;

import javax.crypto.NoSuchPaddingException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.DecryptFileObject;
import biz.capitalware.mqfm.handlers.AES;
import biz.capitalware.mqfm.handlers.IO;
import biz.capitalware.mqfm.handlers.Tokens;

/**
 * This class will handle the DecryptFile action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class DecryptFileAction extends FMAction
{
   private DecryptFileObject   dfo;

   /**
    * The constructor
    * @param dfo
    * @param logger
    */
   public DecryptFileAction(DecryptFileObject dfo)
   {
      super(dfo.actionName);
      this.dfo = dfo;
   }

   /**
    * Perform the sort work.
    */
   public int doWork()
   {
      int exitCode = 0;
      dfo.printValues();

      String toPathAndFilename = Tokens.replace(dfo.actionName, dfo.toFilename, IO.getFileName(dfo.srcFilename), 1, MQFM.userProperties);

      try
      {
         AES aes = new AES(dfo.crypto.passPhrase, dfo.crypto.keySize);
         aes.decrypt(new FileInputStream(dfo.srcFilename), new FileOutputStream(toPathAndFilename));
         dfo.fileCount++;

         MQFM.logger.info("Successfully decrypted '" + dfo.srcFilename + "' to file '" + toPathAndFilename + "'");
      }
      catch (InvalidKeyException e)
      {
         MQFM.logger.fatal("InvalidKeyException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());
         exitCode = 8;
      }
      catch (NoSuchAlgorithmException e)
      {
         MQFM.logger.fatal("NoSuchAlgorithmException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (NoSuchPaddingException e)
      {
         MQFM.logger.fatal("NoSuchPaddingException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (InvalidAlgorithmParameterException e)
      {
         MQFM.logger.fatal("InvalidAlgorithmParameterException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (UnsupportedEncodingException e)
      {
         MQFM.logger.fatal("UnsupportedEncodingException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (FileNotFoundException e)
      {
         MQFM.logger.fatal("FileNotFoundException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: "+e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         exitCode = 8;
      }

      if (!dfo.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }
}
