package biz.capitalware.mqfm.actions;

import java.lang.reflect.Field;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.handlers.ProcessActions;
import biz.capitalware.mqfm.action.objects.FMObject;
import biz.capitalware.mqfm.action.objects.IfObject;
import biz.capitalware.mqfm.handlers.StringUtilities;
import biz.capitalware.mqfm.objects.FieldOfAction;

public class IfAction extends FMAction
{
   private IfObject   io;

   public IfAction(IfObject io)
   {
      super(io.actionName);
      this.io = io;
   }

   /**
    * 
    */
   public int doWork()
   {
      int      exitCode = 0;
      boolean  conditionalTest = false;
      io.printValues();

      FMObject fmo = MQFM.actionObjectValues.get(io.ifLabelName+"_"+io.ifActionName);
      
      if (fmo != null)
      {
         FieldOfAction foa = getFieldFromClass(fmo, io.ifFieldName);
         
         if (foa != null)
         {
            if (foa.value instanceof Integer)
               conditionalTest = conditionalIntTest(foa);
            else if (foa.value instanceof String)
               conditionalTest = conditionalStringTest(foa);
            else if (foa.value instanceof Boolean)
               conditionalTest = conditionalBooleanTest(foa);
            else if (foa.value instanceof Character)
               conditionalTest = conditionalCharacterTest(foa);
            else
            {
               MQFM.logger.fatal("If Action: Unknown class: "+foa.value);
               exitCode = 16; 
            }
         
            if (conditionalTest)
            {
               if (io.actionAL != null)
                  exitCode = ProcessActions.doWork(io.actionAL);
            }
            else
            {
               /* the IF failed therefore do the ELSE */
               
               if (io.eo.actionAL != null)
                  exitCode = ProcessActions.doWork(io.eo.actionAL);
               
               if (io.eo.exitRC != 0)
                  exitCode = io.eo.exitRC;

               if (!io.eo.onErrorFail)
                  exitCode = 0; /* reset back to zero */
            }
         }
         else
            exitCode = 16; /* cannot find Action field */
      }
      else
         exitCode = 16; /* cannot find Action in hashtable */

      if (!io.onErrorFail)
         exitCode = 0; /* reset back to zero */
      
      return exitCode;
   }

   /**
    * 
    * @param fmo
    * @param fieldName
    * @return
    */
   private FieldOfAction getFieldFromClass(FMObject fmo, String fieldName)
   {
      FieldOfAction foa = null;
      Class c = fmo.getClass();
      
      try
      {
         Field f = c.getField(fieldName);
         
         foa = new FieldOfAction();
         foa.name = f.getName();
         foa.type = f.getType().getName();
         foa.value = f.get(fmo);
      }
      catch (SecurityException e)
      {
         MQFM.logger.fatal("SecurityException: " + e.getLocalizedMessage());
      }
      catch (NoSuchFieldException e)
      {
         MQFM.logger.fatal("NoSuchFieldException: " + e.getLocalizedMessage());
      }
      catch (IllegalArgumentException e)
      {
         MQFM.logger.fatal("IllegalArgumentException: " + e.getLocalizedMessage());
      }
      catch (IllegalAccessException e)
      {
         MQFM.logger.fatal("IllegalAccessException: " + e.getLocalizedMessage());
      }
      
      return foa;
   }
   
   /**
    * 
    * @param foa
    * @return
    */
   private boolean conditionalIntTest(FieldOfAction foa)
   {
      boolean  conditionalTest = false;
      
      int v = StringUtilities.stringToInt(io.value, 0);
      int fv = foa.getValueInt();

      MQFM.logger.info("conditionalIntTest: "+foa.name+" of "+foa.getValueInt()+" "+io.operator+" "+v+" ?");
      
      if ("EQ".equals(io.operator))
      {
         if (fv == v)
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      if ("NE".equals(io.operator))
      {
         if (fv != v)
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      else if ("LT".equals(io.operator))
      {
         if (fv < v)
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      else if ("LE".equals(io.operator))
      {
         if (fv <= v)
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      else if ("GT".equals(io.operator))
      {
         if (fv > v)
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      else if ("GE".equals(io.operator))
      {
         if (fv >= v)
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      
      return conditionalTest;
   }
   
   /**
    * 
    * @param foa
    * @return
    */
   private boolean conditionalStringTest(FieldOfAction foa)
   {
      boolean  conditionalTest = false;

      MQFM.logger.info("conditionalStringTest: "+foa.name+" of "+foa.getValueString()+" "+io.operator+" "+io.value+" ?");
      
      if ("EQ".equals(io.operator))
      {
         if (io.value.equalsIgnoreCase(foa.getValueString()))
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      if ("NE".equals(io.operator))
      {
         if (!(io.value.equalsIgnoreCase(foa.getValueString())))
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      
      return conditionalTest;
   }
   
   /**
    * 
    * @param foa
    * @return
    */
   private boolean conditionalBooleanTest(FieldOfAction foa)
   {
      boolean  conditionalTest = false;
      
      boolean v = false;
      if (io.value.equalsIgnoreCase("true"))
         v = true;

      MQFM.logger.info("conditionalIntTest: "+foa.name+" of "+foa.getValueBoolean()+" "+io.operator+" "+v+" ?");
      
      if ("EQ".equals(io.operator))
      {
         if ( v == foa.getValueBoolean())
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      if ("NE".equals(io.operator))
      {
         if ( v != foa.getValueBoolean())
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      
      return conditionalTest;
   }
   
   /**
    * 
    * @param foa
    * @return
    */
   private boolean conditionalCharacterTest(FieldOfAction foa)
   {
      boolean  conditionalTest = false;
      
      char v = io.value.charAt(0);

      MQFM.logger.info("conditionalIntTest: "+foa.name+" of "+foa.getValueBoolean()+" "+io.operator+" "+v+" ?");
      
      if ("EQ".equals(io.operator))
      {
         if ( v == foa.getValueCharacter())
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      if ("NE".equals(io.operator))
      {
         if ( v != foa.getValueCharacter())
            conditionalTest = true;
         else
            conditionalTest = false;
      }
      
      return conditionalTest;
   }
}
