package biz.capitalware.mqfm.actions;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.MergeObject;
import biz.capitalware.mqfm.handlers.IO;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.MQFMException;

/**
 * This class will handle the Merge action.
 * 
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MergeAction extends FMAction
{
   private MergeObject mo;

   /**
    * The constructor
    * 
    * @param mo
    * @param logger
    */
   public MergeAction(MergeObject mo)
   {
      super(mo.actionName);
      this.mo = mo;
   }

   /**
    * Perform the merge work.
    */
   public int doWork()
   {
      int exitCode = 0;
      mo.printValues();

      mo.toFilename = Tokens.replace(mo.actionName, mo.toFilename, mo.srcFilenames[0], 1, MQFM.userProperties);

      try
      {
         mo.srcFilenames = IO.buildStringArrayOfFiles(mo.srcFilenames);
         
         try
         {
            IO.mergeFiles(mo.srcFilenames, mo.toFilename);
            mo.fileCount++;

            MQFM.logger.info("Successfully merged files into " + mo.toFilename);
         }
         catch (MQFMException e)
         {
            exitCode = 8;
         }
      }
      catch (MQFMException e1)
      {
         exitCode = 8;
      }

      if (!mo.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }
}
