package biz.capitalware.mqfm.actions;

import java.io.File;
import java.io.IOException;
import java.util.List;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.MergeSortObject;
import biz.capitalware.mqfm.handlers.ExternalSort;
import biz.capitalware.mqfm.handlers.ExternalSortComparator;
import biz.capitalware.mqfm.handlers.IO;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.MQFMException;

/**
 * This class will handle the MergeSort action.
 * 
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MergeSortAction extends FMAction
{
   private MergeSortObject mso;

   /**
    * The constructor
    * 
    * @param mso
    * @param logger
    */
   public MergeSortAction(MergeSortObject mso)
   {
      super(mso.actionName);
      this.mso = mso;
   }

   /**
    * Perform the mergeSort work.
    */
   public int doWork()
   {
      int exitCode = 0;
      File tempFile;
      mso.printValues();

      mso.toFilename = Tokens.replace(mso.actionName, mso.toFilename, mso.srcFilenames[0], 1, MQFM.userProperties);

      try
      {
         mso.srcFilenames = IO.buildStringArrayOfFiles(mso.srcFilenames);
         
         try
         {
            tempFile = File.createTempFile(biz.capitalware.mqfm.MQFM.WHO_AM_I+"_"+mso.actionName+"_", ".tmp");
            
            // Delete temp file when program exits.
            tempFile.deleteOnExit();      
            
            IO.mergeFiles(mso.srcFilenames, tempFile.getAbsolutePath());

            String toPathAndFilename = Tokens.replace(mso.actionName, mso.toFilename, IO.getFileName(mso.srcFilenames[0]), 1, MQFM.userProperties);

            ExternalSortComparator esc = new ExternalSortComparator(mso);
            List<File> l = ExternalSort.sortInBatch(new File(tempFile.getAbsolutePath()), esc) ;
            ExternalSort.mergeSortedFiles(l, new File(toPathAndFilename), esc);
            
            if (!(tempFile.delete()))
               MQFM.logger.fatal("Error: Cannot delete temporary file: "+tempFile.getAbsolutePath());
            
            mso.fileCount++;

            MQFM.logger.info("Successfully merged and sortd files into " + mso.toFilename);
         }
         catch (IOException e)
         {
            MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            MQFM.globalErrorText = e.getLocalizedMessage();
            exitCode = 8;
         }
         catch (MQFMException e)
         {
            exitCode = 8;
         }
      }
      catch (MQFMException e1)
      {
         exitCode = 8;
      }

      if (!mso.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }
}
