package biz.capitalware.mqfm.actions;

import java.io.File;
import java.io.IOException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.MoveObject;
import biz.capitalware.mqfm.handlers.IO;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.MQFMException;

/**
 * This class will handle the move action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MoveAction extends FMAction
{
   private MoveObject   mo;

   /**
    * The constructor
    * @param mo
    * @param logger
    */
   public MoveAction(MoveObject mo)
   {
      super(mo.actionName);
      this.mo = mo;
   }

   /**
    * Perform the move work.
    */
   public int doWork()
   {
      int exitCode = 0;
      mo.printValues();

      if (mo.srcFilename.indexOf('*') != -1)
         exitCode = handleManyFile();
      else
         exitCode = handleOneFile();

      if (!mo.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }

   /**
    * Move a single file
    * @return exitCode
    */
   private int handleOneFile()
   {
      int exitCode = 0;
      String toPathAndFilename;
      String toFilename = mo.toFilename;

      if (toFilename == null)
         toFilename = IO.getFileName(mo.srcFilename);

      toPathAndFilename = IO.apendFileToPath(mo.targetDir, toFilename);

      toPathAndFilename = Tokens.replace(mo.actionName, toPathAndFilename, IO.getFileName(mo.srcFilename), 1, MQFM.userProperties);

      try
      {
         IO.copyFile(mo.srcFilename, toPathAndFilename);
         IO.deleteFile(mo.srcFilename);
         mo.fileCount++;
      }
      catch (MQFMException e)
      {
         exitCode = 8;
      }

      return exitCode;
   }

   /**
    * Move a many files
    * @return exitCode
    */
   private int handleManyFile()
   {
      int exitCode = 0;
      String toPathAndFilename;
      File[] fileList;
      
      try
      {
         fileList = IO.getFilteredFileList(mo.srcFilename);

         for (int i=0; i < fileList.length; i++)
         {
            String toFilename;

            if (mo.toFilename == null)
               toFilename = fileList[i].getName();
            else
               toFilename = mo.toFilename;

            toPathAndFilename = IO.apendFileToPath(mo.targetDir, toFilename);

            toPathAndFilename = Tokens.replace(mo.actionName, toPathAndFilename, fileList[i].getName(), i+1, MQFM.userProperties);

            IO.copyFile(fileList[i].toString(), toPathAndFilename);
            IO.deleteFile(fileList[i].toString());
            mo.fileCount++;
         }
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 8;
      }
      catch (MQFMException e)
      {
         exitCode = 8;
      }

      return exitCode;
   }
}
