package biz.capitalware.mqfm.actions;

import java.io.File;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.RenameObject;
import biz.capitalware.mqfm.handlers.Tokens;

/**
 * This class will handle the rename action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class RenameAction extends FMAction
{
   private RenameObject   ro;

   /**
    * The constructor
    * @param ro
    * @param logger
    */
   public RenameAction(RenameObject ro)
   {
      super(ro.actionName);
      this.ro = ro;
   }

   /**
    * Perform the move work.
    */
   public int doWork()
   {
      int exitCode = 0;
      String toPathAndFilename = ro.toFilename;
      ro.printValues();

      // File (or directory) with old name
      File file = new File(ro.srcFilename);

      toPathAndFilename = Tokens.replace(ro.actionName, toPathAndFilename, ro.srcFilename, 1, MQFM.userProperties);

      // File (or directory) with new name
      File file2 = new File(toPathAndFilename);

      // Rename file (or directory)
      if (file.renameTo(file2))
      {
         ro.fileCount++;
         MQFM.logger.info("Successfully renamed file: "+ro.srcFilename+ " to " + toPathAndFilename);
      }         
      else
      {
         MQFM.logger.fatal("Cannot rename file: " + ro.srcFilename);
         
         if (ro.onErrorFail)
            exitCode = 8;
      }

      return exitCode;
   }
}
