package biz.capitalware.mqfm.actions;

import java.io.IOException;

import org.jdom.JDOMException;

import com.ibm.mq.MQException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.SendObject;
import biz.capitalware.mqfm.mq.MQPutFile;
import biz.capitalware.mqfm.mq.objects.MQObject;
import biz.capitalware.mqfm.objects.MQFMException;

/**
 * This class will handle the action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class SendAction extends FMAction
{
   private SendObject      so;
   private MQObject        mq;

   /**
    * The constructor
    * @param so
    * @param logger
    */
   public SendAction(SendObject so)
   {
      super(so.actionName);
      this.so = so;
   }

   /**
    * Perform the send work.
    */
   public int doWork()
   {
      int exitCode = 0;
      MQPutFile mqh = null;
      so.printValues();

      mq = new MQObject(so.qMgrName, so.qObject, so.mqXMLFile, so.CCDTFile);

      try
      {
         mq.checkQM();
         mq.DumpUserParms();

         mqh = new MQPutFile(mq);

         mqh.connect();

         if (so.srcFilename.indexOf('*') != -1)
            exitCode = mqh.putManyMsgs(so);
         else
            exitCode = mqh.simplePut1(so);
      }
      catch (JDOMException e)
      {
         MQFM.logger.fatal("JDOMException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (MQException e)
      {
         MQFM.logger.fatal("MQException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal("MQException: " + e.getCause());
         MQFM.logger.fatal("MQCC=" + e.completionCode + " : MQRC="+e.reasonCode);
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (MQFMException e)
      {
         MQFM.logger.fatal("MQFMException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (Exception e)
      {
         MQFM.logger.fatal(e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      finally
      {
         if ( mqh != null)
            mqh.disconnect();
      }

      if (!so.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }
}
