package biz.capitalware.mqfm.actions;

import java.io.File;
import java.io.IOException;
import java.util.List;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.SortObject;
import biz.capitalware.mqfm.handlers.ExternalSort;
import biz.capitalware.mqfm.handlers.ExternalSortComparator;
import biz.capitalware.mqfm.handlers.IO;
import biz.capitalware.mqfm.handlers.Tokens;

/**
 * This class will handle the sort action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class SortAction extends FMAction
{
   private SortObject   so;

   /**
    * The constructor
    * @param so
    * @param logger
    */
   public SortAction(SortObject so)
   {
      super(so.actionName);
      this.so = so;
   }

   /**
    * Perform the sort work.
    */
   public int doWork()
   {
      int exitCode = 0;
      so.printValues();

      String toPathAndFilename = Tokens.replace(so.actionName, so.toFilename, IO.getFileName(so.srcFilename), 1, MQFM.userProperties);
      
      try
      {
         ExternalSortComparator esc = new ExternalSortComparator(so);
         List<File> l = ExternalSort.sortInBatch(new File(so.srcFilename), esc);
         ExternalSort.mergeSortedFiles(l, new File(toPathAndFilename), esc);
         
         so.fileCount++;

         MQFM.logger.info("Successfully sorted '" + so.srcFilename + "' to file '" + toPathAndFilename + "'");
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();

         if (so.onErrorFail)
            exitCode = 8;
      }

      return exitCode;
   }
}
