package biz.capitalware.mqfm.actions;

import java.io.File;
import java.io.IOException;

import com.ice.tar.Tar;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.UnTarObject;
import biz.capitalware.mqfm.handlers.Tokens;

/**
 * This class will handle the UnTar action.
 * 
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class UnTarAction extends FMAction
{
   private UnTarObject uto;

   /**
    * The constructor
    * 
    * @param uto
    * @param logger
    */
   public UnTarAction(UnTarObject uto)
   {
      super(uto.actionName);
      this.uto = uto;
   }

   /**
    * Perform the untar work.
    */
   public int doWork()
   {
      int exitCode = 0;
      uto.printValues();

      uto.tarFilename = Tokens.replace(uto.actionName, uto.tarFilename, uto.targetDir, 1, MQFM.userProperties);

      try
      {
         Tar.extractFiles(new File(uto.tarFilename), new File(uto.targetDir));
         uto.fileCount++;

         MQFM.logger.info("Successfully extracted archive '" + uto.tarFilename + "' to '" + uto.targetDir + "'");
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         MQFM.globalErrorText = e.getLocalizedMessage();
         
         if (uto.onErrorFail)
            exitCode = 8;
      }

      return exitCode;
   }
}
