package biz.capitalware.mqfm.actions;

import java.io.IOException;
import java.util.Date;

import javax.swing.Timer;

import org.jdom.JDOMException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.action.objects.SendObject;
import biz.capitalware.mqfm.action.objects.WatchObject;
import biz.capitalware.mqfm.mq.objects.MQObject;
import biz.capitalware.mqfm.watch.TimerListener;
import biz.capitalware.mqfm.watch.Watch;
import biz.capitalware.mqfm.xml.WatchXml;

/**
 * This class will handle watch action.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class WatchAction extends FMAction
{
   private WatchObject     wo;
   private Timer           timer;
   private TimerListener   timerListener;

   /**
    * The constructor
    * @param wo
    * @param logger
    */
   public WatchAction(WatchObject wo)
   {
      super(wo.actionName);
      this.wo = wo;
   }

   /**
    * Perform the watch work.
    */
   public int doWork()
   {
      int exitCode = 0;
      Thread currentThread = null;

      try
      {

         WatchXml wxh = new WatchXml();
         wxh.setWatchObject(wo);
         wxh.readXMLFile(wo.xmlFile);

         Watch[] watches = wxh.getWatches();

         wo.printValues();
         MQFM.logger.info("     PollInterval         = " + (wxh.getPollInterval()/1000));
         
         for (int i=0; i < watches.length; i++)
         {
            MQFM.logger.info("     ---- Watching #"+(i+1)+" ----");
            SendObject so = watches[i].getSendObject();
            MQObject tempMQ = new MQObject(so.qMgrName, so.qObject, so.mqXMLFile, so.CCDTFile);
            tempMQ.checkQM();
            tempMQ.DumpUserParms();
            so.printValues(false);
            watches[i].printValues();
            watches[i].setMQObject(tempMQ);
         }

         currentThread = Thread.currentThread();
         Runtime.getRuntime().addShutdownHook(new ShutdownThread(currentThread));

         timerListener = new TimerListener(watches);
         timer = new Timer(wxh.getPollInterval(), timerListener);
         timer.start();

         // do your work until the thread is interrupted
         try
         {
            while (!currentThread.isInterrupted())
            {
               Thread.sleep(1000);
            }
         }
         catch (InterruptedException e)
         {
            MQFM.logger.info("Watch wait loop was interrupted.");
         }

         MQFM.logger.info("Beginning cleanup to exit.");

         timer.stop();

         for (int i=0; (i < 3) && timerListener.isWorking();i++)
         {
            if (timerListener.isWorking())
               try {Thread.sleep(1000);} catch (InterruptedException e){}
         }
      }
      catch (JDOMException e)
      {
         MQFM.logger.fatal("JDOMException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (IOException e)
      {
         MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      catch (Exception e)
      {
         MQFM.logger.fatal("Exception: " + e.getLocalizedMessage());
         if (e.getCause() != null)
            MQFM.logger.fatal(e.getCause().toString());;
         MQFM.globalErrorText = e.getLocalizedMessage();
         exitCode = 99;
      }
      finally
      {
         MQFM.logger.info("Sending notifiction.");
         if (currentThread != null)
         {
            // notify controller thread that we have finished
            synchronized (currentThread)
            {
               currentThread.notify();
               MQFM.logger.info("Sent notifiction.");
            }
         }
      }

      MQFM.logger.info("All done - time to exit.");

      if (!wo.onErrorFail)
         exitCode = 0; /* reset back to zero */

      return exitCode;
   }

   /**
    * This class will handle the shutdown.
    *
    */
   private static class ShutdownThread extends Thread
   {
      private Thread workerThread;

      /**
       * The constructor
       * @param workerThread
       * @param logger
       */
      public ShutdownThread(Thread workerThread)
      {
         this.workerThread = workerThread;
      }

      /**
       * Do the work.
       */
      public void run()
      {
         MQFM.logger.info("WatchAction: Shutdown requested at " + new Date());

         // request worker thread to finish
         workerThread.interrupt();

         // wait for the worker thread to finish
         try
         {
            synchronized (workerThread)
            {
               workerThread.wait();
            }
         }
         catch (InterruptedException e)
         {}
         MQFM.logger.info("WatchAction: Shutdown at " + new Date());
      }
   }
}
