package biz.capitalware.mqfm.handlers;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.List;

import org.jdom.JDOMException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.objects.JobObject;
import biz.capitalware.mqfm.xml.JobXml;

/**
 * This class will handle running an external program.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class RunJob
{
   private   JobObject        job;
   private   String           jobName;
   private   StringBuffer     errorSB = null;

   /**
    * The constructor
    * @param logger
    */
   public RunJob()
   {
      super();
   }

   /**
    * Setup and launch an external program
    * @param jobXmlFile
    * @throws IOException
    * @throws JDOMException
    */
   public void launch(String jobXmlFile) throws JDOMException, IOException
   {
      this.jobName = jobXmlFile;
      JobXml jxh = new JobXml();
      jxh.readXMLFile(jobXmlFile);
      job = jxh.getJob();

      if (job.isWait())
      {
         executeCmd();
      }
      else
      {
         Thread t = new Thread(new Runner());
         t.start();
      }
   }

   /**
    * Setup and launch an external program
    * @param jobXmlFile
    * @param errorText
    * @throws IOException
    * @throws JDOMException
    */
   public void launch(String jobXmlFile, String errorText) throws JDOMException, IOException
   {
      this.jobName = jobXmlFile;
      JobXml jxh = new JobXml();
      jxh.readXMLFile(jobXmlFile);
      job = jxh.getJob();
      if (errorText != null)
         errorSB = new StringBuffer(errorText);

      if (job.isWait())
      {
         executeCmd();
      }
      else
      {
         Thread t = new Thread(new Runner());
         t.start();
      }
   }

   /**
    * Common code to launch a separate external process.
    * @throws IOException
    */
   private void executeCmd() throws IOException
   {
      List<String> command = new ArrayList<String>();
      command.add(job.getCmd());
      String[] parms = job.getParms();
      for (int i = 0; i < parms.length; i++)
         command.add(Tokens.replace(parms[i], errorSB));

      MQFM.logger.info("CMD: " + command.toString());

      ProcessBuilder builder = new ProcessBuilder(command);
//         Map<String, String> environ = builder.environment();

      if (job.getWorkingDirectory() != null)
         builder.directory(new File(job.getWorkingDirectory()));

      Process process = builder.start();
      InputStream is = process.getInputStream();
      InputStreamReader isr = new InputStreamReader(is);
      BufferedReader br = new BufferedReader(isr);
      String line;
      while ((line = br.readLine()) != null)
      {
         MQFM.logger.info("<Output> " + line);
      }

      MQFM.logger.info("External program for '" +jobName + "' terminated.");
   }

   /**
    * This class will build and run the external in a separate thread.
    */
   class Runner implements Runnable
   {
      public void run()
      {
         MQFM.logger.info("Starting a new thread to run the external program.");
         try
         {
            executeCmd();
         }
         catch (IOException e)
         {
            MQFM.logger.fatal("IOException: " + e.getLocalizedMessage());
            if (e.getCause() != null)
               MQFM.logger.fatal(e.getCause().toString());
         }
      }
   }
}
