package biz.capitalware.mqfm.mq;

import com.ibm.mq.MQSecurityExit;

import biz.capitalware.mqausx.MQAUSXJ;
import biz.capitalware.mqausx.MQAUSXJ2EE;
import biz.capitalware.mqfm.mq.objects.MQObject;

/**
 * This class will instantiate either MQAUSXJ or MQAUSXJ2EE client-side security exit. 
 * MQAUSXJ or MQAUSXJ2EE are Java classes from Capitalware MQAUSX product.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class CWSX
{
   /**
    * The constructor - make sure nothing instantiates this class.
    * It must be accessed in a static way.
    */
   private CWSX()
   {}

   /**
    * Instantiate either MQAUSXJ or MQAUSXJ2EE client-side security exit.
    * @param mqo
    * @return ausxj
    */
   public static MQSecurityExit getMQAUSXJ(MQObject mqo)
   {
      MQSecurityExit ausxj = null;
      
      if ("biz.capitalware.mqausx.MQAUSXJ2EE".equals(mqo.securityExit))
      {
         if (mqo.securityExitData != null)
            ausxj = new MQAUSXJ2EE(mqo.securityExitData);
         else if ( (mqo.userID != null) && (mqo.password != null) )
            ausxj = new MQAUSXJ2EE(mqo.userID, mqo.password);
         else
            ausxj = new MQAUSXJ2EE();
      }
      else
      {
         if (mqo.securityExitData != null)
            ausxj = new MQAUSXJ(mqo.securityExitData);
         else if ( (mqo.userID != null) && (mqo.password != null) )
            ausxj = new MQAUSXJ(mqo.userID, mqo.password);
         else
            ausxj = new MQAUSXJ();
      }

      return ausxj;
   }
}
