package biz.capitalware.mqfm.mq;

/**
 * A class to parse the TMC structure
 *
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.1
 * @license Apache 2 License
 */
public class MQTrigger
{
   private String _structId;
   private String _version;
   private String _qName;
   private String _processName;
   private String _triggerData;
   private String _applType;
   private String _applId;
   private String _envData;
   private String _userData;
   private String _qMgrName;

   /**
    * The constructor
    * @param String
    */
   public MQTrigger(String tmcStruct) throws StringIndexOutOfBoundsException
   {
      super();

      _structId    = tmcStruct.substring(0,3).trim();
      _version     = tmcStruct.substring(4,8).trim();
      _qName       = tmcStruct.substring(8,55).trim();
      _processName = tmcStruct.substring(56,103).trim();
      _triggerData = tmcStruct.substring(104,167).trim();
      _applType    = tmcStruct.substring(168,171).trim();
      _applId      = tmcStruct.substring(172,427).trim();
      _envData     = tmcStruct.substring(428,555).trim();
      _userData    = tmcStruct.substring(556,683).trim();

      /**
       * The TMC version 2 structure includes the queue manager name
       * which is not present in a version 1 structure.
       */
      if (_version.compareTo(new String("2")) == 0)
         _qMgrName = tmcStruct.substring(684, 732).trim();
      else
         _qMgrName = "";
   }

   /**
    * Retrieve the TMC Structure ID
    * @return String
    */
   public String getStructId()
   {
      return _structId;
   }

   /**
    * Retrieve the TMC Structure version
    * @return String
    */
   public String getVersion()
   {
      return _version;
   }

   /**
    * Retrieve the queue name from the TMC structure
    * @return String
    */
   public String getQueueName()
   {
      return _qName;
   }

   /**
    * Retrieve the process name from the TMC structure
    * @return String
    */
   public String getProcessName()
   {
      return _processName;
   }

   /**
    * Retrieve the trigger data from the TMC structure
    * @return String
    */
   public String getTriggerData()
   {
      return _triggerData;
   }

   /**
    * Retrieve the application type from the TMC structure
    * @return String
    */
   public String getApplicationType()
   {
      return _applType;
   }

   /**
    * Retrieve the trigger data from the TMC structure
    * @return String
    */
   public String getApplicationId()
   {
      return _applId;
   }

   /**
    * Retrieve the environment data from the TMC structure
    * @return String
    */
   public String getEnvironmentData()
   {
      return _envData;
   }

   /**
    * Retrieve the user data from the TMC structure
    * @return String
    */
   public String getUserData()
   {
      return _userData;
   }

   /**
    * Retrieve the queue manager name from the TMC structure
    * @return String
    */
   public String getQueueManagerName()
   {
      return _qMgrName;
   }
}
