package biz.capitalware.mqfm.mq.objects;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;

import org.jdom.JDOMException;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.xml.MQXml;

/**
 * This class holds the MQ information.
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.1
 * @license Apache 2 License
 */
public class MQObject
{
   public String                       qMgrName = null;
   public QueueObject                  qObject = null;
   public ArrayList<QueueObject>       disListOfQNames = null;
   public String                       hostname = null;
   public String                       channelName = null;
   public int                          port = -1;
   //
   public String                       userID = null;
   public String                       password = null;
   //
   public String                       securityExit = null;
   public String                       securityExitPath = null;
   public String                       securityExitData = null;
   //
   public String                       cipherSuiteName = null;
   public String                       distinguishedName = null;
   public String                       trustedStore = null;
   public String                       trustedStorePasswd = null;
   public String                       keyStore = null;
   public String                       keyStorePasswd = null;
   public String                       ldapServer = null;
   public int                          ldapServerPort = -1;
   //
   public String                       CCDTFile = null;
   public String                       mqXmlFile = null;

   /*
    * The constructor
    */
   public MQObject(String qMgrName, QueueObject qObject, String mqXmlFile, String CCDTFile)
   {
      super();
      this.qMgrName = qMgrName;
      this.qObject = qObject;
      this.mqXmlFile = mqXmlFile;
      this.CCDTFile = CCDTFile;
   }

   /**
    *
    * @throws IOException
    * @throws JDOMException
    */
   public void checkQM() throws IOException, JDOMException
   {
      if (mqXmlFile != null)
      {
         MQXml mqp = new MQXml();
         mqp.readXMLFile(mqXmlFile);

         /*
          * Only retrieve the following values if they are not null 
          */
         if ((mqp.getQMgrName() != null) && (qMgrName == null))
            qMgrName = mqp.getQMgrName();

         if ((mqp.getQueueName() != null) && (qObject == null))
            qObject = mqp.getQueueName();

         if ((mqp.getCCDTFile() != null) && (CCDTFile == null))
            CCDTFile = mqp.getCCDTFile();
         
         disListOfQNames = mqp.getDisListOfQNames();
         hostname = mqp.getHostname();
         channelName = mqp.getChannelName();
         port = mqp.getPort();
         //
         userID = mqp.getUserID();
         password = mqp.getPassword();
         //
         securityExit = mqp.getSecurityExit();
         securityExitPath = mqp.getSecurityExitPath();
         securityExitData = mqp.getSecurityExitData();
         //
         cipherSuiteName = mqp.getCipherSuiteName();
         distinguishedName = mqp.getDistinguishedName();
         trustedStore = mqp.getTrustedStore();
         trustedStorePasswd = mqp.getTrustedStorePasswd();
         keyStore = mqp.getKeyStore();
         keyStorePasswd = mqp.getKeyStorePasswd();
         ldapServer = mqp.getLdapServer();
         ldapServerPort = mqp.getLdapServerPort();
      }

      if ( ("".equals(qMgrName)) || (qMgrName == null) )
         throw new IllegalArgumentException("Missing a required XML tag: QMgrName within MQ");

      if ( (qObject == null) && (disListOfQNames == null) )
         throw new IllegalArgumentException("Missing value. Specify either a queue name or a distribution list.");

      if ( (("".equals(qObject)) || (qObject == null)) && (disListOfQNames == null) )
         throw new IllegalArgumentException("Missing a required XML tag: QueueName within MQ");
      
      if ( (userID == null) && (password != null) )
         throw new IllegalArgumentException("Cannot have a Password without a UserID: UserID within MQ");

      if ((hostname != null) || (channelName != null))
      {
         if (hostname == null)
            throw new IllegalArgumentException("Missing the XML tag: Hostname within MQFM_MQ.");
         if (channelName == null)
            throw new IllegalArgumentException("Missing the XML tag: ChannelName within MQFM_MQ.");

         if (CCDTFile != null)
            throw new IllegalArgumentException("The user cannot specify both channelname/hostname/port and CCDTFile.  Please specify only one method of connecting to the remote queue manager.");
      }
      else if (CCDTFile != null)
      {
         boolean exists = (new File(CCDTFile)).exists();
         if ( !(exists) )
            throw new IllegalArgumentException("Error: The CCDT file does not exists : " + CCDTFile);
      }
   }

   /**
    * Dump the common user supplied parameters.
   * @param logger
    */
   public void DumpUserParms()
   {
      MQFM.logger.info("     Queue Manager Name   = " + qMgrName);
      
      if (disListOfQNames != null)
      {
         StringBuffer sb = new StringBuffer();
         for (int i=0; i < disListOfQNames.size(); i++)
         {
            if (i != 0)
               sb.append(", ");
            QueueObject mqdlo = disListOfQNames.get(i);
            
            if (mqdlo.qMgrName != null)
               sb.append(mqdlo.qMgrName+" / "+mqdlo.qName);
            else
               sb.append(mqdlo.qName);
         }
         
         MQFM.logger.info("     Distribution List    = "+sb.toString());
      }
      else
      {
         MQFM.logger.info("     Queue Name           = " + qObject.qName);
         if (qObject.qMgrName != null)
            MQFM.logger.info("     Remote QMgr Name     = " + qObject.qMgrName);
      }

      if (channelName != null)
      {
         MQFM.logger.info("     Channel Name         = " + channelName);
         MQFM.logger.info("     Hostname             = " + hostname);
         MQFM.logger.info("     Port Number          = " + port);

         if (userID != null)
            MQFM.logger.info("     UserID               = " + userID);

         if (password != null)
            MQFM.logger.info("     Password             = *****");

         if (securityExit != null)
            MQFM.logger.info("     SecurityExit         = " + securityExit);

         if (securityExitPath != null)
            MQFM.logger.info("     SecurityExitPath     = " + securityExitPath);

         if (securityExitData != null)
            MQFM.logger.info("     SecurityExitData     = " + securityExitData);

         if (cipherSuiteName != null)
            MQFM.logger.info("     Cipher Suite Name    = " + cipherSuiteName);

         if (distinguishedName != null)
            MQFM.logger.info("     Distinguished Name   = " + distinguishedName);

         if (trustedStore != null)
            MQFM.logger.info("     Trusted Store        = " + trustedStore);

         if (trustedStorePasswd != null)
            MQFM.logger.info("     Trusted StorePasswd  = " + trustedStorePasswd);

         if (keyStore != null)
            MQFM.logger.info("     Key Store            = " + keyStore);

         if (keyStorePasswd != null)
            MQFM.logger.info("     Key Store Passwd     = " + keyStorePasswd);

         if (ldapServer != null)
         {
            MQFM.logger.info("     LDAP Server          = " + ldapServer);
            MQFM.logger.info("     LDAP ServerPort      = " + ldapServerPort);
         }

         if (System.getProperty("javax.net.ssl.trustStore") != null)
            MQFM.logger.info("     javax.net.ssl.trustStore = " + System.getProperty("javax.net.ssl.trustStore"));

         if (System.getProperty("javax.net.ssl.trustStorePassword") != null)
            MQFM.logger.info("     javax.net.ssl.trustStorePassword = " + System.getProperty("javax.net.ssl.trustStorePassword"));

         if (System.getProperty("javax.net.ssl.keyStore") != null)
            MQFM.logger.info("     javax.net.ssl.keyStore = " + System.getProperty("javax.net.ssl.keyStore"));

         if (System.getProperty("javax.net.ssl.keyStore") != null)
            MQFM.logger.info("     javax.net.ssl.keyStorePassword = " + System.getProperty("javax.net.ssl.keyStorePassword"));
      }
      else if (CCDTFile != null)
      {
         MQFM.logger.info("     CCDT                 = " + CCDTFile);

         if (userID != null)
            MQFM.logger.info("     UserID               = " + userID);

         if (password != null)
            MQFM.logger.info("     Password             = *****");
      }
   }
}
