package biz.capitalware.mqfm.objects;

import java.io.File;

import com.ibm.mq.MQC;

/**
 * This class holds the constant values.
 *
 * @author Roger Lacroix, Capitalware Inc.
 * @version 3.0
 * @license Apache 2 License
 */
public class Constants
{
   /**
    * The constructor - make sure nothing instantiates this class.
    * It must be accessed in a static way.
    */
   private Constants()
   {}

   public static final String    VERSION              = "4.1.8";

   public static final String    HOME_PATH            = System.getProperty("user.dir") + File.separator + "data" + File.separator;
   public static final String    ARCHIVE_PATH         = System.getProperty("user.dir") + File.separator + "archive" + File.separator;
   public static final String    EMAIL_PATH           = System.getProperty("user.dir") + File.separator + "email" + File.separator;
   public static final String    JOBS_PATH            = System.getProperty("user.dir") + File.separator + "jobs" + File.separator;
   public static final String    MQ_PATH              = System.getProperty("user.dir") + File.separator + "mq" + File.separator;
   public static final String    SCHEDULE_PATH        = System.getProperty("user.dir") + File.separator + "schedule" + File.separator;
   public static final String    WATCH_PATH           = System.getProperty("user.dir") + File.separator + "watch" + File.separator;
   public static final String    XML_SUFFIX           = ".xml";

   public static final String    LOG4J_APPENDER_MQFM  = "mqfm";
   
   public static final String    SERVICE_FILE_NAME    = "service.properties";

   public static final String    QUIT_MSG             = "QUIT";

   public static final int       MAX_GROUP_MSG_SIZE   = 4190000;   // 4MB - 4304

   public static final String    HOSTNAME_TOKEN       = "${HOSTNAME}";
   public static final String    IPADDRESS_TOKEN      = "${IPADDRESS}";

   public static final int       MQTMC_V1_LENGTH      = 684;
   public static final int       MQTMC_V2_LENGTH      = 732;

   /*
    * Flag to determine how to run Receive action
    */
   public static final char      ONE_PASS          = 'S';  // single
   public static final char      RUN_UNTIL_EMPTY   = 'E';  // empty
   public static final char      TRIGGERED         = 'T';  // triggered
   public static final char      DAEMON            = 'D';  // Unix daemon or Windows service
   
   /*
    * Flag for the format of the message
    */
   public static final char      FORMAT_STRING     = 'S';
   public static final char      FORMAT_ZIP        = 'Z';

   /*
    * Different alerts for 3rd party central management systems
    */
   public static final int       ALERT_SUCCESS              = 1;
   public static final int       ALERT_INFO                 = 2;
   public static final int       ALERT_DEBUG                = 3;
   public static final int       ALERT_ERROR                = 4;
   public static final int       ALERT_FATAL                = 5;
   public static final int       ALERT_INVALID_PARAMETERS   = 6;
   public static final int       ALERT_UKNOWN_ACTION        = 7;
   public static final int       ALERT_JDOM                 = 8;
   public static final int       ALERT_IO                   = 9;
   public static final int       ALERT_UNSATISFIED_LINK     = 10;
   public static final int       ALERT_MQ                   = 11;
   public static final int       ALERT_STARTING             = 12;
   public static final int       ALERT_TERMINATING          = 13;
   
   /*
    * The marker is the high order 16 bits i.e.  x'0011 0000'
    * The lower 16-bits are used as a flag.
    */
   public  final static int MQFM_MSG = MQC.MQFB_APPL_FIRST + 1048576;
   /*
    * Low order 16-bits.  This means we can up to 16 flags.
    */
   public  final static int MQFM_ZIP_MSG           = MQFM_MSG + 1;  //  bit 0000 0000 0000 0001
   public  final static int MQFM_START_JOB         = MQFM_MSG + 2;  //  bit 0000 0000 0000 0010
   public  final static int MQFM_XML_EMBEDDED_MSG  = MQFM_MSG + 4;  //  bit 0000 0000 0000 0100
   public  final static int MQFM_ENCRYPT_MSG       = MQFM_MSG + 8;  //  bit 0000 0000 0000 1000
   public  final static int MQFM_ZIP_ENCRYPT_MSG   = MQFM_MSG + 9;  //  bit 0000 0000 0000 1001
   
   /**
    * XML related elements and attributes
    */
   public static final String XML_PROLOG              = "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?><!DOCTYPE MQFM_Msg>";
   public static final String MQFM_MSG_ELEMENT        = "MQFM_Msg";
   //
//   public static final String NAME_ELEMENT            = "Name";
   /**
    * MQFM Major Elements
    */
   public static final String GLOBAL_ELEMENT          = "Global";
   public static final String ACTIONS_ELEMENT         = "Actions";
   /**
    * Action elements
    */
   public static final String SEND_ELEMENT            = "Send";
   public static final String WATCH_ELEMENT           = "Watch";
   public static final String RECEIVE_ELEMENT         = "Receive";
   public static final String PUTQUIT_ELEMENT         = "PutQuit";
   public static final String EXECUTE_ELEMENT         = "Execute";
   public static final String IF_ELEMENT              = "If";
   public static final String ELSE_ELEMENT            = "Else";
   public static final String LAUNCH_ELEMENT          = "Launch";
   public static final String SCHEDULE_ELEMENT        = "Schedule";
   public static final String SEND_EMAIL_ELEMENT      = "SendEmail";
   public static final String SLEEP_ELEMENT           = "Sleep";
   public static final String APPEND_ELEMENT          = "Append";
   public static final String COPY_ELEMENT            = "Copy";
   public static final String DECRYPT_FILE_ELEMENT    = "DecryptFile";
   public static final String DELETE_ELEMENT          = "Delete";
   public static final String ENCRYPT_FILE_ELEMENT    = "EncryptFile";
   public static final String MERGE_ELEMENT           = "Merge";
   public static final String MERGE_SORT_ELEMENT      = "MergeSort";
   public static final String MOVE_ELEMENT            = "Move";
   public static final String RENAME_ELEMENT          = "Rename";
   public static final String REPLACE_TEXT_ELEMENT    = "ReplaceText";
   public static final String SORT_ELEMENT            = "Sort";
   public static final String TAR_ELEMENT             = "Tar";
   public static final String TOUCH_ELEMENT           = "Touch";
   public static final String UNTAR_ELEMENT           = "UnTar";
   public static final String UNZIP_ELEMENT           = "UnZip";
   public static final String ZIP_ELEMENT             = "Zip";
   /**
    * MQ Elements
    */
   public static final String MQ_ELEMENT                 = "MQ";
   public static final String MQFILE_ELEMENT             = "MQFile";
   public static final String CCDTFILE_ELEMENT           = "CCDTFile";
   public static final String CORREL_ID_ELEMENT          = "CorrelId";
   public static final String QMGRNAME_ELEMENT           = "QMgrName";
   public static final String QUEUENAME_ELEMENT          = "QueueName";
   public static final String DISTRIBUTIONLIST_ELEMENT   = "DistributionList";
   //
   public static final String HOSTNAME_ELEMENT           = "Hostname";
   public static final String PORT_ELEMENT               = "Port";
   public static final String CHANNELNAME_ELEMENT        = "ChannelName";
   public static final String USERID_ELEMENT             = "UserID";
   public static final String PASSWORD_ELEMENT           = "Password";
   public static final String SECURITYEXIT_ELEMENT       = "SecurityExit";
   public static final String SECURITYEXITPATH_ELEMENT   = "SecurityExitPath";
   public static final String SECURITYEXITDATA_ELEMENT   = "SecurityExitData";
   public static final String CIPHERSUITENAME_ELEMENT    = "CipherSuiteName";
   public static final String DISTINGUISHEDNAME_ELEMENT  = "DistinguishedName";
   public static final String TRUSTEDSTORE_ELEMENT       = "TrustedStore";
   public static final String TRUSTEDSTOREPASSWD_ELEMENT = "TrustedStorePasswd";
   public static final String KEYSTORE_ELEMENT           = "KeyStore";
   public static final String KEYSTOREPASSWD_ELEMENT     = "KeyStorePasswd";
   public static final String LDAPSERVER_ELEMENT         = "LDAPServer";
   public static final String LDAPSERVERPORT_ELEMENT     = "LDAPServerPort";
   /*
    * Global Elements
    */
   public static final String PROPERTY_ELEMENT        = "Property";
   public static final String LOGFILE_ELEMENT         = "LogFile";
   public static final String ON_ERROR_ELEMENT        = "OnError";

   /**
    * General Elements
    */
   public static final String WATCH_SEND_ELEMENT      = "WatchSend";
   public static final String FILE_ELEMENT            = "File";
   public static final String WATCHFILE_ELEMENT       = "WatchFile";
   public static final String BACKOUTQNAME_ELEMENT    = "BackOutQName";
   public static final String STATUSQNAME_ELEMENT     = "StatusQName";
   public static final String ARCHIVE_ELEMENT         = "Archive";
   public static final String REMOTE_ELEMENT          = "Remote";
   public static final String DIRECTORY_ELEMENT       = "Directory";
   public static final String DEFAULT_ELEMENT         = "Default";
   public static final String FILENAME_ELEMENT        = "FileName";
   /**
    * Job Elements
    */
   public static final String JOB_ELEMENT             = "Job";
   public static final String COMMAND_ELEMENT         = "Command";
   public static final String PARM_ELEMENT            = "Parm";
   /**
    * Email Elements
    */
   public static final String SMTP_HOST_ELEMENT       = "SmtpHost";
   public static final String SMTP_PORT_ELEMENT       = "SmtpPort";
   public static final String SMTP_USERID_ELEMENT     = "SmtpUserID";
   public static final String SMTP_PASSWORD_ELEMENT   = "SmtpPassword";
   public static final String FROM_EMAIL_ELEMENT      = "FromEmailAddress";
   public static final String TO_EMAIL_ELEMENT        = "ToEmailAddress";
   public static final String EMAIL_SUBJECT_ELEMENT   = "Subject";
   public static final String EMAIL_MSG_TEXT_ELEMENT  = "MessageText";
   /**
    * Watch Elements
    */
   public static final String POLL_INTERVAL_ELEMENT   = "PollInterval";
   public static final String EXTENSION_ELEMENT       = "Extension";
   /**
    * Schedule Elements
    */
   public static final String MINUTE_ELEMENT          = "Minute";
   public static final String HOUR_ELEMENT            = "Hour";
   public static final String DAYOFMONTH_ELEMENT      = "DayOfMonth";
   public static final String MONTH_ELEMENT           = "Month";
   public static final String DAYOFWEEK_ELEMENT       = "DayOfWeek";
   public static final String YEAR_ELEMENT            = "Year";
   /**
    * ReplaceText Elements
    */
   public static final String FIND_ELEMENT            = "Find";
   public static final String REPLACE_ELEMENT         = "Replace";
   /**
    * Attributes
    */
   public static final String ON_ERROR_FAIL_ATTRIBUTE = "onerrorfail";
   public static final String USE_FILE_LOCKING        = "usefilelocking";
   public static final String DELETE_ATTRIBUTE        = "delete";
   public static final String FORMAT_ATTRIBUTE        = "format";
   public static final String GETWITHCONVERT_ATTRIBUTE= "getwithconvert";
   public static final String RUN_ATTRIBUTE           = "run";
   public static final String OVERRIDE_ATTRIBUTE      = "override";
   public static final String TO_DIR_ATTRIBUTE        = "todir";
   public static final String TO_FILE_ATTRIBUTE       = "tofile";
   public static final String FILE_ATTRIBUTE          = "file";
   public static final String XML_FILE_ATTRIBUTE      = "xmlfile";
   public static final String DIR_ATTRIBUTE           = "dir";
   public static final String NAME_ATTRIBUTE          = "name";
   public static final String VALUE_ATTRIBUTE         = "value";
   public static final String WAIT_ATTRIBUTE          = "wait";
   public static final String TYPE_ATTRIBUTE          = "type";
   public static final String PRIORITY_ATTRIBUTE      = "priority";
   public static final String PERSISTENCE_ATTRIBUTE   = "persistence";
   public static final String SEND_ON_STARTUP         = "sendonstartup";
   public static final String COLUMN_ATTRIBUTE        = "column";
   public static final String ORDER_ATTRIBUTE         = "order";
   public static final String ROWS_ATTRIBUTE          = "rows";
   public static final String COLUMNS_ATTRIBUTE       = "columns";
   public static final String SSL_ATTRIBUTE           = "ssl";
   public static final String AUTHENTICATION_ATTRIBUTE= "authentication";
   public static final String KEY_SIZE_ATTRIBUTE      = "keysize";
   public static final String PASS_PHRASE_ATTRIBUTE   = "passphrase";
   public static final String HOURS_ATTRIBUTE         = "hours";
   public static final String MINUTES_ATTRIBUTE       = "minutes";
   public static final String SECONDS_ATTRIBUTE       = "seconds";
   public static final String MILLISECONDS_ATTRIBUTE  = "milliseconds";
   public static final String LABEL_ATTRIBUTE         = "label";
   public static final String LABEL_NAME_ATTRIBUTE    = "labelname";
   public static final String ACTION_NAME_ATTRIBUTE   = "actionname";
   public static final String FIELD_NAME_ATTRIBUTE    = "fieldname";
   public static final String OPERATOR_ATTRIBUTE      = "operator";
   public static final String EXIT_RC_ATTRIBUTE       = "exitrc";
   public static final String QMGRNAME_ATTRIBUTE      = "qmgrname";
   public static final String APPEND_ATTRIBUTE        = "append";
   public static final String CREATE_DIR_ATTRIBUTE    = "createdir";
}
