package biz.capitalware.mqfm.objects;

import java.util.ArrayList;

/**
 * This class holds the Job information.
 * @author Roger Lacroix, Capitalware Inc.
 * @version 1.0
 * @license Apache 2 License
 */
public class JobObject
{
   private String             _name = null;
   private String             _cmd = null;
   private ArrayList<String>  _jobAL;
   private String             _workingDirectory = null;
   private boolean            _wait = true;

   /**
    * The constructor
    */
   public JobObject(String name, String cmd, ArrayList<String>  al, String directory, String wait)
   {
      super();

      this._name = name;
      this._cmd = cmd;
      this._jobAL = al;
      this._workingDirectory = directory;

      if ( (wait.charAt(0) == 'N') || (wait.charAt(0) == 'n') )
         _wait = false;
   }

   /**
    * Retrieve the Job name
    * @return name
    */
   public String getName()
   {
      return _name;
   }

   /**
    * Retrieve the runtime command
    * @return cmd
    */
   public String getCmd()
   {
      return _cmd;
   }

   /**
    * Retrieve the runtime parameters
    * @return parms
    */
   public String[] getParms()
   {
      String[] parms = new String[_jobAL.size()];

      for (int i=0; i < _jobAL.size(); i++)
         parms[i] = _jobAL.get(i);

      return parms;
   }

   /**
    * Retrieve the working directory value
    * @return workingDirectory
    */
   public String getWorkingDirectory()
   {
      return _workingDirectory;
   }

   /**
    * Should MQFM wait for the job to complete?
    * @return wait
    */
   public boolean isWait()
   {
      return _wait;
   }
}
