package biz.capitalware.mqfm.objects;

import biz.capitalware.mqfm.handlers.StringUtilities;

/**
 * Exception thrown when an entry is past the date
 * 
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class PastDateException extends Exception
{
   private static final long serialVersionUID = 1L;
   
   protected int errorCode = 0;
   protected String errorMessage = "";

   /**
    * Creates a new past date exception
    */
   public PastDateException()
   {
      super();
   }

   /**
    * Creates a new past date exception given a message string
    * 
    * @param str
    *           Message string associated to the exception
    */
   public PastDateException(String str)
   {
      super(str);
   }

   /**
    * PastDateException constructor calls super
    * 
    * @param int errorCode
    * @param String
    *           str
    */
   public PastDateException(int errorCode, String str)
   {
      super(str);

      this.errorCode = errorCode;
      this.errorMessage = str;
   }

   /**
    * PastDateException constructor calls super
    * 
    * @param String
    *           sErrorCode
    * @param String
    *           strException
    */
   public PastDateException(String sErrorCode, String strException)
   {

      super(strException);
      this.errorCode = StringUtilities.stringToInt(sErrorCode, 0);
      this.errorMessage = strException;
   }

   /**
    * Retreive the error code integer.
    * 
    * @return int
    */
   public int getErrorCode()
   {
      return this.errorCode;
   }

   /**
    * Retreive the error message text.
    * 
    * @return String
    */
   public String getErrorMessage()
   {
      return this.errorMessage;
   }
}
