package biz.capitalware.mqfm.watch;

import java.io.*;
import java.util.ArrayList;

import biz.capitalware.mqfm.MQFM;

/**
 * FileWatch extends the general Watch class and implements the abstract check
 * method for a single file.
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class FileWatch extends Watch
{
   private long lastModified;

   /**
    * @param filename
    *           Filename of file to watch
    */
   public FileWatch(String filename)
   {
      super(filename);
   }

   /**
    * Checks File for changes
    *
    * @return filename + date when modification occurred, null if no modification
    *         was detected
    */
   public ArrayList<String> check()
   {
      ArrayList<String> al = new ArrayList<String>();
      File file = new File(_completePathToTarget);
      long modified = file.lastModified();
      if (modified > lastModified)
      {
         al.add(_completePathToTarget);
         lastModified = modified;
      }

      return al;
   }

   /**
    * Output the values used by this class.
    */
   public void printValues()
   {
      MQFM.logger.info("     Filename to be monitored = " + _completePathToTarget);
   }

   /**
    * Reset the last modified time stamp
    */
   public void resetLastModified(String filename)
   {
      lastModified = 0;
   }
}
