package biz.capitalware.mqfm.xml;

import org.jdom.*;
import org.jdom.input.*;

import biz.capitalware.mqfm.MQFM;
import biz.capitalware.mqfm.handlers.Tokens;
import biz.capitalware.mqfm.objects.Constants;
import biz.capitalware.mqfm.objects.JobObject;

import java.util.*;
import java.io.*;

/**
 * This class handles the reading and parsing of Job XML file and parse parameters
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class JobXml extends FMXml
{
   private JobObject       _job;

   /**
    * The constructor
    * @param logger
    */
   public JobXml()
   {
      super();
   }

   /**
    * Read Job XML file and set parameters
    *
    * @param xmlFilename
    *           Filename of job.xml file
    * @throws IOException
    */
   public void readXMLFile(String jobXmlFile) throws JDOMException, IOException
   {
      SAXBuilder builder = new SAXBuilder(true);
      Document doc = builder.build(Constants.JOBS_PATH + jobXmlFile);
      Element rootElement = doc.getRootElement();
      // get main element
      Element jobElement = rootElement.getChild(Constants.JOB_ELEMENT);
      String jobNameAttr = null;
      if (jobElement.getAttribute(Constants.NAME_ATTRIBUTE) != null)
         jobNameAttr = Tokens.replace("Execute", jobElement.getAttribute(Constants.NAME_ATTRIBUTE).getValue(), MQFM.userProperties);

      Element cmdElement = jobElement.getChild(Constants.COMMAND_ELEMENT);
      String cmd = Tokens.replace("Execute", cmdElement.getTextTrim(), MQFM.userProperties);

      String wait= cmdElement.getAttribute(Constants.WAIT_ATTRIBUTE).getValue();

      String workingDirectory = null;
      if ( jobElement.getChild(Constants.DIRECTORY_ELEMENT) != null)
         workingDirectory = Tokens.replace("Execute", jobElement.getChild(Constants.DIRECTORY_ELEMENT).getTextTrim(), MQFM.userProperties);

      List parmList = jobElement.getChildren(Constants.PARM_ELEMENT);
      ArrayList<String> jobAL = new ArrayList<String>();
      Iterator it = parmList.iterator();
      while (it.hasNext())
      {
         Element parmElement = (Element) it.next();
         jobAL.add(Tokens.replace("Execute", parmElement.getTextTrim(), MQFM.userProperties));
      }

      _job = new JobObject(jobNameAttr, cmd, jobAL, workingDirectory, wait);

      MQFM.logger.info("Values used for this Job:");
      MQFM.logger.info("    Job Name            = " + (jobNameAttr == null?"":jobNameAttr));
      MQFM.logger.info("    Command             = " + cmd);
      for (int i=0; i < jobAL.size(); i++)
         MQFM.logger.info("    Parm["+(i+1)+"]             = " + jobAL.get(i));
      MQFM.logger.info("    Working Directory   = " + (workingDirectory == null?"":workingDirectory));
      MQFM.logger.info("    Wait for job        = " + wait);
   }

   /**
    * Retrieve the job structure
    * @return job
    */
   public JobObject getJob()
   {
      return _job;
   }
}
