package biz.capitalware.mqfm.xml;

import java.io.*;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.jdom.*;
import org.jdom.input.*;

import biz.capitalware.mqfm.handlers.StringUtilities;
import biz.capitalware.mqfm.mq.objects.QueueObject;
import biz.capitalware.mqfm.objects.Constants;

/**
 * This class handles the reading and parsing of MQ XML file and parse parameters
 *
 * @author Roger Lacroix
 * @version 1.0
 * @license Apache 2 License
 */
public class MQXml extends FMXml
{
   private String                      _qMgrName = null;
   private QueueObject                 _qObject = null;
   private ArrayList<QueueObject>      _disListOfQNames = null; 
   private String                      _fileCCDT = null;
   private String                      _hostname = null;
   private String                      _channelName = null;
   private String                      _port = null;
   private String                      _userID = null;
   private String                      _password = null;
   private String                      _securityExit = null;
   private String                      _securityExitPath = null;
   private String                      _securityExitData = null;
   //
   private String                      _cipherSuiteName = null;
   private String                      _distinguishedName = null;
   private String                      _trustedStore = null;
   private String                      _trustedStorePasswd = null;
   private String                      _keyStore = null;
   private String                      _keyStorePasswd = null;
   private String                      _ldapServer = null;
   private String                      _ldapServerPort = null;

   /**
    * The constructor
    * @param logger
    */
   public MQXml()
   {
      super();
   }

   /**
    * Read MQ XML file and set parameters
    *
    * @param xmlFilename
    *           Filename of job.xml file
    * @throws IOException
    */
   public void readXMLFile(String xmlFileName) throws JDOMException, IOException
   {
      SAXBuilder builder = new SAXBuilder(true);
      Document doc = builder.build(Constants.MQ_PATH + xmlFileName);
      Element rootElement = doc.getRootElement();
      Element disListElement = null;
      Element queueElement = null;

      if ( rootElement.getChild(Constants.QMGRNAME_ELEMENT) != null)
         _qMgrName = rootElement.getChild(Constants.QMGRNAME_ELEMENT).getTextTrim();

      /* Distribution list?  */
      if ( (disListElement = rootElement.getChild(Constants.DISTRIBUTIONLIST_ELEMENT)) != null)
      {
         QueueObject mqdlo = null;
         _disListOfQNames = new ArrayList<QueueObject>();

         /* We should have at least 2 Queue elements */
         List propertyList = disListElement.getChildren(Constants.QUEUENAME_ELEMENT);
         Iterator it = propertyList.iterator();
         while (it.hasNext())
         {
            queueElement = (Element) it.next();
            
            mqdlo = new QueueObject();
            
            mqdlo.qName = queueElement.getTextTrim();
            
            if (queueElement.getAttribute(Constants.QMGRNAME_ATTRIBUTE) != null)
               mqdlo.qMgrName = queueElement.getAttribute(Constants.QMGRNAME_ATTRIBUTE).getValue().trim();
            else
               mqdlo.qMgrName = null;
            
            _disListOfQNames.add(mqdlo);
         }
      }
      else
      {  /* Queue name */
         if ( (queueElement = rootElement.getChild(Constants.QUEUENAME_ELEMENT)) != null)
         {
            _qObject = new QueueObject();
            _qObject.qName = queueElement.getTextTrim();
            
            if (queueElement.getAttribute(Constants.QMGRNAME_ATTRIBUTE) != null)
               _qObject.qMgrName = queueElement.getAttribute(Constants.QMGRNAME_ATTRIBUTE).getValue().trim();
            else
               _qObject.qMgrName = null;
         }
      }

      if ( rootElement.getChild(Constants.CCDTFILE_ELEMENT) != null)
         _fileCCDT = rootElement.getChild(Constants.CCDTFILE_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.HOSTNAME_ELEMENT) != null)
         _hostname = rootElement.getChild(Constants.HOSTNAME_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.PORT_ELEMENT) != null)
         _port = rootElement.getChild(Constants.PORT_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.CHANNELNAME_ELEMENT) != null)
         _channelName = rootElement.getChild(Constants.CHANNELNAME_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.USERID_ELEMENT) != null)
         _userID = rootElement.getChild(Constants.USERID_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.PASSWORD_ELEMENT) != null)
         _password = rootElement.getChild(Constants.PASSWORD_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.SECURITYEXIT_ELEMENT) != null)
         _securityExit = rootElement.getChild(Constants.SECURITYEXIT_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.SECURITYEXITPATH_ELEMENT) != null)
         _securityExitPath = rootElement.getChild(Constants.SECURITYEXITPATH_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.SECURITYEXITDATA_ELEMENT) != null)
         _securityExitData = rootElement.getChild(Constants.SECURITYEXITDATA_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.CIPHERSUITENAME_ELEMENT) != null)
         _cipherSuiteName = rootElement.getChild(Constants.CIPHERSUITENAME_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.DISTINGUISHEDNAME_ELEMENT) != null)
         _distinguishedName = rootElement.getChild(Constants.DISTINGUISHEDNAME_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.TRUSTEDSTORE_ELEMENT) != null)
         _trustedStore = rootElement.getChild(Constants.TRUSTEDSTORE_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.TRUSTEDSTOREPASSWD_ELEMENT) != null)
         _trustedStorePasswd = rootElement.getChild(Constants.TRUSTEDSTOREPASSWD_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.KEYSTORE_ELEMENT) != null)
         _keyStore = rootElement.getChild(Constants.KEYSTORE_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.KEYSTOREPASSWD_ELEMENT) != null)
         _keyStorePasswd = rootElement.getChild(Constants.KEYSTOREPASSWD_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.LDAPSERVER_ELEMENT) != null)
         _ldapServer = rootElement.getChild(Constants.LDAPSERVER_ELEMENT).getTextTrim();

      if ( rootElement.getChild(Constants.LDAPSERVERPORT_ELEMENT) != null)
         _ldapServerPort = rootElement.getChild(Constants.LDAPSERVERPORT_ELEMENT).getTextTrim();
   }

   /**
    * Retrieve the CCDT file.
    * @return fileCCDT
    */
   public String getCCDTFile()
   {
      return _fileCCDT;
   }

   /**
    * Retrieve the queue manager name.
    * @return qmgrname
    */
   public String getQMgrName()
   {
      return _qMgrName;
   }

   /**
    * Retrieve the queue name.
    * @return qname
    */
   public QueueObject getQueueName()
   {
      return _qObject;
   }

   /**
    * Retrieve the distribution list with queue names
    * @return disListOfQNames
    */
   public ArrayList<QueueObject> getDisListOfQNames()
   {
      return _disListOfQNames;
   }

   /**
    * Retrieve the jhostname.
    * @return hostname
    */
   public String getHostname()
   {
      return _hostname;
   }

   /**
    * Retrieve the channel name.
    * @return channelName
    */
   public String getChannelName()
   {
      return _channelName;
   }

   /**
    * Retrieve the port number.
    * @return portnumber
    */
   public int getPort()
   {
      return StringUtilities.stringToInt(_port,1414);
   }

   /**
    * Retrieve the UserID.
    * @return userID
    */
   public String getUserID()
   {
      return _userID;
   }

   /**
    * Retrieve the Password.
    * @return password
    */
   public String getPassword()
   {
      return _password;
   }

   /**
    * Retrieve the security exit name.
    * @return securityExit
    */
   public String getSecurityExit()
   {
      return _securityExit;
   }

   /**
    * Retrieve the security exit path.
    * @return securityExitPath
    */
   public String getSecurityExitPath()
   {
      return _securityExitPath;
   }

   /**
    * Retrieve the security exit user data.
    * @return securityExitData
    */
   public String getSecurityExitData()
   {
      return _securityExitData;
   }

   /**
    * Retrieve the CipherSuiteName.
    * @return cipherSuiteName
    */
   public String getCipherSuiteName()
   {
      return _cipherSuiteName;
   }

   /**
    * Retrieve the Distinguished Name.
    * @return distinguishedName
    */
   public String getDistinguishedName()
   {
      return _distinguishedName;
   }

   /**
    * Retrieve the Trusted Store.
    * @return trustedStore
    */
   public String getTrustedStore()
   {
      return _trustedStore;
   }

   /**
    * Retrieve the Trusted Store Password.
    * @return trustedStorePasswd
    */
   public String getTrustedStorePasswd()
   {
      return _trustedStorePasswd;
   }

   /**
    * Retrieve the KeyStore.
    * @return keyStore
    */
   public String getKeyStore()
   {
      return _keyStore;
   }

   /**
    * Retrieve the Key Store Password.
    * @return keyStorePasswd
    */
   public String getKeyStorePasswd()
   {
      return _keyStorePasswd;
   }

   /**
    * Retrieve the LDAP Server.
    * @return ldapServer
    */
   public String getLdapServer()
   {
      return _ldapServer;
   }

   /**
    * Retrieve the LDAP Server Port number.
    * @return portNum
    */
   public int getLdapServerPort()
   {
      return StringUtilities.stringToInt(_ldapServerPort,389);
   }
}
